@@ -3,7 +3,7 @@ use 5.012;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 use Moo;
 use HTTP::Tiny '0.056';
 use JSON::Tiny qw[decode_json];
@@ -22,45 +22,32 @@ use Finance::Robinhood::Quote;
 use Finance::Robinhood::Watchlist;
 #
 has token => (is => 'ro', writer => '_set_token');
-has account => (
-    is  => 'ro',
-    isa => sub {
-        die "$_[0] is not an ::Account!"
-            unless ref $_[0] eq 'Finance::Robinhood::Account';
-    },
-    builder => 1,
-    lazy    => 1
-);
-
-sub _build_account {
-    my $acct = shift->_accounts();
-    return $acct ? $acct->[0] : ();
-}
 #
 my $base = 'https://api.robinhood.com/';
 
 # Different endpoints we can call for the API
 my %endpoints = (
-                'accounts'              => 'accounts/',
-                'accounts/portfolios'   => 'portfolios/',
-                'accounts/positions'    => 'accounts/%s/positions/',
-                'ach_deposit_schedules' => 'ach/deposit_schedules/',
-                'ach_iav_auth'          => 'ach/iav/auth/',
-                'ach_relationships'     => 'ach/relationships/',
-                'ach_transfers'         => 'ach/transfers/',
-                'applications'          => 'applications/',
-                'dividends'             => 'dividends/',
-                'document_requests'     => 'upload/document_requests/',
-                'edocuments'            => 'documents/',
-                'fundamentals'          => 'fundamentals/%s',
-                'instruments'           => 'instruments/',
-                'login'                 => 'api-token-auth/',
-                'logout'                => 'api-token-logout/',
-                'margin_upgrades'       => 'margin/upgrades/',
-                'markets'               => 'markets/',
-                'notifications'         => 'notifications/',
-                'notifications/devices' => 'notifications/devices/',
-                'cards'                 => 'midlands/notifications/stack/',
+                'accounts'               => 'accounts/',
+                'accounts/positions'     => 'accounts/%s/positions/',
+                'portfolios'             => 'portfolios/',
+                'portfolios/historicals' => 'portfolios/historicals/',
+                'ach_deposit_schedules'  => 'ach/deposit_schedules/',
+                'ach_iav_auth'           => 'ach/iav/auth/',
+                'ach_relationships'      => 'ach/relationships/',
+                'ach_transfers'          => 'ach/transfers/',
+                'applications'           => 'applications/',
+                'dividends'              => 'dividends/',
+                'document_requests'      => 'upload/document_requests/',
+                'edocuments'             => 'documents/',
+                'fundamentals'           => 'fundamentals/%s',
+                'instruments'            => 'instruments/',
+                'login'                  => 'api-token-auth/',
+                'logout'                 => 'api-token-logout/',
+                'margin_upgrades'        => 'margin/upgrades/',
+                'markets'                => 'markets/',
+                'notifications'          => 'notifications/',
+                'notifications/devices'  => 'notifications/devices/',
+                'cards'                  => 'midlands/notifications/stack/',
                 'cards/dismiss' => 'midlands/notifications/stack/%s/dismiss/',
                 'orders'        => 'orders/',
                 'password_reset'          => 'password_reset/',
@@ -359,8 +346,20 @@ sub quote {
         : ();
 }
 
-sub quote_price {
-    return shift->quote(shift)->[0]{last_trade_price};
+sub historicals {
+    my $self = ref $_[0] ? shift : ();    # might be undef but that's okay
+    my ($symbol, $interval, $span) = @_;
+    my ($status, $data, $raw)
+        = _send_request($self,
+                        'GET',
+                        Finance::Robinhood::endpoint('quotes/historicals')
+                            . "$symbol/?interval=$interval&$span"
+        );
+    return if $status != 200;
+    for (@{$data->{historicals}}) {
+        $_->{begins_at} = _2_datetime($_->{begins_at});
+    }
+    return $data->{historicals};
 }
 
 sub locate_order {
@@ -374,16 +373,17 @@ sub locate_order {
 
 sub list_orders {
     my ($self, $type) = @_;
-    my $result = $self->_send_request('GET',
-                                      Finance::Robinhood::endpoint('orders')
-                                          . (ref $type
-                                                 && ref $type eq 'HASH'
-                                                 && defined $type->{cursor}
-                                             ?
-                                                 '?cursor=' . $type->{cursor}
-                                             : ''
-                                          )
-    );
+    my $result =
+        $self->_send_request('GET',
+                             Finance::Robinhood::endpoint('orders')
+                                 . (ref $type
+                                        && ref $type eq 'HASH'
+                                        && defined $type->{cursor}
+                                    ?
+                                        '?cursor=' . $type->{cursor}
+                                    : ''
+                                 )
+        );
     $result // return !1;
     return () if !$result;
     return $self->_paginate($result, 'Finance::Robinhood::Order');
@@ -416,11 +416,10 @@ sub notifications_devices {
 
 sub create_watchlist {
     my ($self, $name) = @_;
-    my $result = $self->_send_request('POST',
-                                      Finance::Robinhood::endpoint(
-                                                                'watchlists'),
-                                      {name => $name}
-    );
+    my $result =
+        $self->_send_request('POST',
+                             Finance::Robinhood::endpoint('watchlists'),
+                             {name => $name});
     return $result ?
         Finance::Robinhood::Watchlist->new(rh => $self, %$result)
         : ();
@@ -438,18 +437,17 @@ sub delete_watchlist {
 
 sub watchlists {
     my ($self, $cursor) = @_;
-    my $result = $self->_send_request('GET',
-                                      Finance::Robinhood::endpoint(
-                                                                 'watchlists')
-                                          . (
-                                            ref $cursor
-                                                && ref $cursor eq 'HASH'
-                                                && defined $cursor->{cursor}
-                                            ?
-                                                '?cursor=' . $cursor->{cursor}
-                                            : ''
-                                          )
-    );
+    my $result =
+        $self->_send_request('GET',
+                             Finance::Robinhood::endpoint('watchlists')
+                                 . (ref $cursor
+                                        && ref $cursor eq 'HASH'
+                                        && defined $cursor->{cursor}
+                                    ?
+                                        '?cursor=' . $cursor->{cursor}
+                                    : ''
+                                 )
+        );
     $result // return !1;
     return () if !$result;
     return $self->_paginate($result, 'Finance::Robinhood::Watchlist');
@@ -577,7 +575,7 @@ sub _2_datetime {
 
 =head1 NAME
 
-Finance::Robinhood - Trade stocks and ETFs with free brokerage Robinhood
+Finance::Robinhood - Trade Stocks and ETFs with Free Brokerage Robinhood
 
 =head1 SYNOPSIS
 
@@ -597,19 +595,40 @@ Finance::Robinhood - Trade stocks and ETFs with free brokerage Robinhood
 This modules allows you to buy, sell, and gather information related to stocks
 and ETFs traded in the U.S. Please see the L<Legal|LEGAL> section below.
 
+By the way, if you're wondering how to buy and sell without lot of reading,
+head over to the L<Finance::Robinhood::Order> and pay special attention to the
+L<order cheat sheet|Finance::Robinhood::Order/"Order Cheat Sheet">.
+
 =head1 METHODS
 
-Finance::Robinhood is...
+Finance::Robinhood wraps a powerfully capable API which has many options.
+There are parts of this package that are object oriented and others which are
+functional. I've attempted to organize everything according to how and when
+they are used... Let's start at the very beginning: Let's log in!
+
+=head1 Logging In
+
+Robinhood requires an authorization token for most API calls. To get this
+token, you must either pass it as an argument to C<new( ... )> or log in with
+your username and password.
 
 =head2 C<new( ... )>
 
-    my $rh = Finance::Robinhood->new( ); # Reqires ->login(...) call
+    # Passing the token is the prefered way of handling authorization
     my $rh = Finance::Robinhood->new( token => ... );
 
-With no arguments, this creates a new Finance::Quote object without account
-information. Before you can buy or sell, you must L<login( ... )|log in> which
-will will return an authorization token which may be used for future logins
-without your username and password.
+This would create a new Finance::Robinhood object ready to go.
+
+    # Reqires ->login(...) call :(
+    my $rh = Finance::Robinhood->new( );
+
+With no arguments, this creates a new Finance::Robinhood object without
+account information. Before you can buy or sell or do almost anything else,
+you must log in manually.
+
+On the bright side, for future logins, you can store the authorization token
+and use it rather than having to pass your username and password around
+anymore.
 
 =head2 C<login( ... )>
 
@@ -619,8 +638,14 @@ without your username and password.
 Logging in allows you to buy and sell securities with your Robinhood account.
 You must do this if you do not have an authorization token.
 
-If login was sucessful, a valid token is returned which should be stored for
-use in future calls to C<new( ... )>.
+If login was successful, a valid token is returned and may also be had by
+calling C<token( )>. The token should be kept secret and stored for use in
+future calls to C<new( ... )>.
+
+=head2 C<token( )>
+
+Now that you've logged in, you might want to securely store authorization info
+to pass to C<new( ... )> next time. Get the authorization token here.
 
 =head2 C<logout( )>
 
@@ -628,25 +653,40 @@ use in future calls to C<new( ... )>.
     # ...do some stuff... buy... sell... idk... stuff... and then...
     $rh->logout( ); # Goodbye!
 
-Logs you out of Robinhood by forcing the token returned by
-C<login( ... )> or passed to C<new(...)> to expire.
+Logs you out of Robinhood by forcing the token returned by C<login( ... )> or
+passed to C<new(...)> to expire.
 
 I<Note>: This will log you out I<everywhere> because Robinhood generates a
-single authorization token per account at a time!
+single authorization token per account at a time! This is good in rare case
+your token is stolen.
 
 =head2 C<forgot_password( ... )>
 
     Finance::Robinhood::forgot_password('contact@example.com');
 
-This requests a password reset email to be sent from Robinhood.
+It happens. This requests a password reset email to be sent from Robinhood.
 
 =head2 C<change_password( ... )>
 
     Finance::Robinhood::change_password( $username, $password, $token );
 
-Robinhood sends a link to the registered email address when the
-C<password_reset( ... )> function is called. In the email there is a link with
-the username and a token. You must provide a new password.
+When you've forgotten your password, the email Robinhood send contains a link
+to an online form where you may change your password. That link has a token
+you may use here to change the password as well.
+
+=head1 User Information
+
+Brokerage firms must collect a lot of information about their customers due to
+IRS and SEC regulations. They also keep data to identify you internally.
+Here's how to access all of the data you entered when during registration and
+beyond.
+
+=head2 C<user_id( )>
+
+    my $user_id = $rh->user_id( );
+
+Returns the ID Robinhood uses to identify this particular account. You could
+also gather this information with the C<user_info( )> method.
 
 =head2 C<user_info( )>
 
@@ -656,23 +696,16 @@ the username and a token. You must provide a new password.
 Returns very basic information (name, email address, etc.) about the currently
 logged in account as a hash.
 
-=head2 C<user_id( )>
-
-    my $user_id = $rh->user_id( );
-
-Returns the ID Robinhood uses to identify this particular account. You could
-also gather this information with the C<user_info( )> method.
-
 =head2 C<basic_info( )>
 
-This method grabs more private information about the user including their date
-of birth, marital status, and the last four digits of their social security
-number.
+This method grabs basic but more private information about the user including
+their date of birth, marital status, and the last four digits of their social
+security number.
 
 =head2 C<additional_info( )>
 
 This method grabs information about the user that the SEC would like to know
-including any affilations with publically traded securities.
+including any affiliations with publicly traded securities.
 
 =head2 C<employment_info( )>
 
@@ -688,14 +721,35 @@ the survey performed during registration.
 
 Returns a paginated list of identification information.
 
+=head1 Accounts
+
+A user may have access to more than a single Robinhood account. Each account
+is represented by a Finance::Robinhood::Account object internally. Orders to
+buy and sell securities require an account object. The object also contains
+information about your financial standing.
+
+For more on how to use these objects, please see the
+Finance::Robinhood::Account docs.
+
 =head2 C<accounts( ... )>
 
-Returns a paginated list of Finance::Robinhood::Account objects related to the
-currently logged in user.
+This method returns a paginated list of Finance::Robinhood::Account objects
+related to the currently logged in user.
 
 I<Note>: Not sure why the API returns a paginated list of accounts. Perhaps
 in the future a single user will have access to multiple accounts?
 
+=head2 Financial Instruments
+
+Financial Instrument is a fancy term for any equity, asset, debt, loan, etc.
+but we'll strictly be referring to securities (stocks and ETFs) as financial
+instruments.
+
+We use blessed Finance::Robinhood::Instrument objects to represent securities
+in order transactions, watchlists, etc. It's how we'll refer to a security so
+looking over the documentation found in Finance::Robinhood::Instrument would
+be a wise thing to do.
+
 =head2 C<instrument( ... )>
 
     my $msft = $rh->instrument('MSFT');
@@ -708,7 +762,8 @@ returned as a Finance::Robinhood::Instrument object.
     my $msft = Finance::Robinhood::instrument({id => '50810c35-d215-4866-9758-0ada4ac79ffa'});
 
 If a hash reference is passed with an C<id> key, the single result is returned
-as a Finance::Robinhood::Instrument object.
+as a Finance::Robinhood::Instrument object. The unique ID is how Robinhood
+identifies securities internally.
 
     my $results = $rh->instrument({query => 'solar'});
     my $results = Finance::Robinhood::instrument({query => 'solar'});
@@ -730,19 +785,32 @@ them, use the C<next> or C<previous> values.
 Returns a sample list of top securities as Finance::Robinhood::Instrument
 objects along with C<next> and C<previous> cursor values.
 
+=head1 Orders
+
+Now that you've L<logged in|/"Logging In"> and
+L<found the particular stock|/"Financial Instruments"> you're interested in,
+you probably want to buy or sell something. You do this by placing orders.
+
+Orders are created by using the constructor found in Finance::Robinhood::Order
+directly so have a look at the documentation there (especially the small cheat
+sheet).
+
+Once you've place the order, you'll want to keep track of them somehow. To do
+this, you may use either of the following methods.
+
 =head2 C<locate_order( ... )>
 
     my $order = $rh->locate_order( $order_id );
 
-Returns a blessed Finance::Robinhood::Order object related to the about the
-buy or sell order with the given id.
+Returns a blessed Finance::Robinhood::Order object related to the buy or sell
+order with the given id if it exits.
 
 =head2 C<list_orders( ... )>
 
     my $orders = $rh->list_orders( );
 
 Requests a list of all orders ordered from newest to oldest. Executed and even
-cancelled orders are returned in a C<results> key as Finance::Robinhood::Order
+canceled orders are returned in a C<results> key as Finance::Robinhood::Order
 objects. Cursor keys C<next> and C<previous> may also be present.
 
     my $more_orders = $rh->list_orders({ cursor => $orders->{next} });
@@ -751,6 +819,12 @@ You'll likely generate more than a hand full of buy and sell orders which
 would generate more than a single page of results. To gather them, use the
 C<next> or C<previous> values.
 
+=head1 Quotes and Historical Data
+
+If you're doing anything beyond randomly choosing stocks with a symbol
+generator, you'll want to know a little more. Robinhood provides access to
+both current and historical data on securities.
+
 =head2 C<quote( ... )>
 
     my %msft = $rh->quote('MSFT');
@@ -766,29 +840,56 @@ symbols, the objects are returned as a paginated list.
 This function has both functional and object oriented forms. The functional
 form does not require an account and may be called without ever logging in.
 
-=head2 C<create_watchlist( ... )>
+=head2 C<historicals( ... )>
 
-    my $watchlist = $rh->create_watchlist( 'Energy' );
+    # Snapshots of basic quote data for every five minutes of the previous day
+    my $msft = $rh->historicals('MSFT', '5minute', 'day');
 
-You can create new Finance::Robinhood::Watchlist objects.
+You may retrieve historical quote data with this method. The first argument is
+a symbol. The second is an interval time and must be either C<5minute>,
+C<10minute>, C<day>, or C<week>.
 
-=head2 C<delete_watchlist( ... )>
+The third argument is a span of time indicating how far into the past you
+would like to retrieve and may be one of the following: C<day>, C<week>,
+C<year>, or C<5year>.
 
-    $rh->delete_watchlist( $watchlist );
+So, to get five years of weekly historical data for Apple, you would write...
 
-You may remove a watchlist with this method.
+    my $iHist = $rh->historicals('AAPL', 'week', '5year');
+    my $gates = Finance::Robinhood::historicals('MSFT', 'week', '5year');
 
-=head2 C<watchlists( ... )>
+This method returns a list of hashes which in turn contain the following keys:
 
-    my $watchlists = $rh->watchlists( );
+=over
 
-Returns all your current watchlists as a paginated list of
-Finance::Robinhood::Watchlists.
+=item C<begins_at> - A DateTime object indicating the timestamp of this block
+of data.
 
-    my $more = $rh->watchlists( { cursor => $watchlists->{next} } );
+=item C<close_price> - The most recent close price during this interval.
 
-In case where you have more than one page of watchlists, use the C<next> and
-C<previous> cursor strings.
+=item C<high_price> - The most recent high price during this interval.
+
+=item C<interpolated> - Indicates whether the data was a statistical estimate.
+This is a boolean value.
+
+=item C<low_price> - The most recent low price during this interval.
+
+=item C<open_price> - The most recent open price during this interval.
+
+=item C<volume> - The trading volume during this interval.
+
+=back
+
+Note that if you already have a Finance::Robinhood::Instrument object, you may
+want to just call the object's C<historicals( $interval, $span )> method which
+wraps this.
+
+This function has both functional and object oriented forms. The functional
+form does not require an account and may be called without ever logging in.
+
+=head1 Informational Cards and Notifications
+
+TODO
 
 =head2 C<cards( )>
 
@@ -816,6 +917,10 @@ C<"https://api.robinhood.com/notifications/stack/4494b413-33db-4ed3-a9d0-714a4ac
 it should be
 C<<"https://api.robinhood.com/B<midlands/>notifications/stack/4494b413-33db-4ed3-a9d0-714a4acd38de/">>.
 
+=head1 Dividends
+
+TODO
+
 =head2 C<dividends( )>
 
 Gathers a paginated list of dividends due (or recently paid) for your account.
@@ -835,11 +940,51 @@ C<results> currently contains a list of hashes which look a lot like this:
       withholding => "0.00",
     }
 
+=head1 Watchlists
+
+You can keep track of a list of securities by adding them to a watchlist. The
+watchlist used by the official Robinhood apps and preloaded with popular
+securities is named 'Default'. You may create new watchlists for
+organizational reasons but the official apps currently only display the
+'Default' watchlist.
+
+Each watchlist is represented by a Finance::Robinhood::Watchlist object.
+Please read the docs for that package to find out how to add and remove
+individual securities.
+
+=head2 C<create_watchlist( ... )>
+
+    my $watchlist = $rh->create_watchlist( 'Energy' );
+
+You can create new Finance::Robinhood::Watchlist objects with this. Here, your
+code would create a new one named "Energy".
+
+=head2 C<delete_watchlist( ... )>
+
+    $rh->delete_watchlist( $watchlist );
+
+You may remove a watchlist with this method.
+
+If you clobber the watchlist named 'Default', it will be recreated with
+popular securities the next time you open any of the official apps.
+
+=head2 C<watchlists( ... )>
+
+    my $watchlists = $rh->watchlists( );
+
+Returns all your current watchlists as a paginated list of
+Finance::Robinhood::Watchlists.
+
+    my $more = $rh->watchlists( { cursor => $watchlists->{next} } );
+
+In case where you have more than one page of watchlists, use the C<next> and
+C<previous> cursor strings.
+
 =head1 LEGAL
 
 This is a simple wrapper around the API used in the official apps. The author
 provides no investment, legal, or tax advice and is not responsible for any
-damages incured while using this software. Neither this software nor its
+damages incurred while using this software. Neither this software nor its
 author are affiliated with Robinhood Financial LLC in any way.
 
 For Robinhood's terms and disclosures, please see their website at http://robinhood.com/
