@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 use Moo;
 use JSON::Tiny qw[decode_json];
 use strictures 2;
@@ -24,6 +24,10 @@ sub quote {
     return Finance::Robinhood::quote(shift->symbol());
 }
 
+sub historicals {
+    return Finance::Robinhood::historicals(shift->symbol(), shift, shift);
+}
+
 sub splits {
 
     # Upcoming stock splits
@@ -57,7 +61,7 @@ sub fundamentals {
 
 =head1 NAME
 
-Finance::Robinhood - Trade stocks and ETFs with free brokerage Robinhood
+Finance::Robinhood::Instrument - Single Financial Instrument
 
 =head1 SYNOPSIS
 
@@ -68,7 +72,7 @@ Finance::Robinhood - Trade stocks and ETFs with free brokerage Robinhood
 =head1 DESCRIPTION
 
 This class represents a single financial instrument. Objects are usually
-created by Finance::Robinhood. If you intend to create your own, please use
+created by Finance::Robinhood so please use
 C<Finance::Robinhood->instrument(...)>.
 
 =head1 METHODS
@@ -80,13 +84,28 @@ This class has several getters and a few methods as follows...
 Makes an API call and returns a Finance::Robinhood::Quote object with current
 data on this security.
 
-=head2 C<market( ... )>
+=head2 C<historicals( ... )>
+
+    $instrument->historicals( 'week', 'year' );
+
+You may retrieve historical quote data with this method which wraps the
+function found in Finance::Robinhood. Please see the documentation for that
+function for more info on what data is returned.
+
+The first argument is an interval time and must be either C<5minute>,
+C<10minute>, C<day>, or C<week>.
+
+The second argument is a span of time indicating how far into the past you
+would like to retrieve and may be one of the following: C<day>, C<week>,
+C<year>, or C<5year>.
+
+=head2 C<market( )>
 
 This makes an API call for information this particular instrument is traded on.
 
 =head2 C<tradeable( )>
 
-Returns a boolean value indicating whether this security is tradeable on
+Returns a boolean value indicating whether this security can be traded on
 Robinhood.
 
 =head2 C<symbol( )>
@@ -151,7 +170,7 @@ Makes and API call and returns a hash containing the following data:
 
 This is a simple wrapper around the API used in the official apps. The author
 provides no investment, legal, or tax advice and is not responsible for any
-damages incured while using this software. Neither this software nor its
+damages incurred while using this software. Neither this software nor its
 author are affiliated with Robinhood Financial LLC in any way.
 
 For Robinhood's terms and disclosures, please see their website at http://robinhood.com/
