@@ -1,7 +1,7 @@
 package Finance::Robinhood::Market;
 use 5.010;
 use Carp;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -24,21 +24,22 @@ sub todays_hours {
 
 =head1 NAME
 
-Finance::Robinhood::Market - Basic market information
+Finance::Robinhood::Market - Basic Market Information
 
 =head1 SYNOPSIS
 
     use Finance::Robinhood::Market;
 
-    my $MC = Finance::Robinhood::Instrument::search('APPL');
+    my $MC = Finance::Robinhood::instrument('APPL');
     my $market = $MC->market();
     print $market->acronym() . ' is based in ' . $market->city();
 
 =head1 DESCRIPTION
 
 This class represents a single financial market. Objects are usually
-created by Finance::Robinhood. If you intend to create your own, please use
-C<Finance::Robinhood->instrument(...)->market()>.
+created by Finance::Robinhood. If you're looking for information about the
+market where a particular security is traded, use
+C<<<Finance::Robinhood::instrument($symbol)->market()>>>.
 
 =head1 METHODS
 
@@ -87,7 +88,7 @@ operating hours for this particular market.
 
 This is a simple wrapper around the API used in the official apps. The author
 provides no investment, legal, or tax advice and is not responsible for any
-damages incured while using this software. Neither this software nor its
+damages incurred while using this software. Neither this software nor its
 author are affiliated with Robinhood Financial LLC in any way.
 
 For Robinhood's terms and disclosures, please see their website at http://robinhood.com/
