@@ -1,7 +1,7 @@
 package Finance::Robinhood::Position;
 use 5.010;
 use Carp;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -58,8 +58,6 @@ This class has several getters and a few methods as follows...
 
 =head2 C<account( )>
 
-    my $acct = $order->account();
-
 Returns the Finance::Robinhood::Account object related to this order.
 
 =head2 C<average_buy_price( )>
@@ -88,11 +86,11 @@ Current number of shares of this security owned by you.
 
 =head2 C<shares_held_for_buys( )>
 
-Number of shares in outstanding (unexecuted) buy orders.
+Number of shares in buy orders which have not fully executed.
 
 =head2 C<shares_held_for_sells( )>
 
-Number of shares held in outstanding (unexecuted) sell orders.
+Number of shares held in sell orders which have not fully executed.
 
 =head2 C<upated_at( )>
 
@@ -102,7 +100,7 @@ Timestamp of the last change made to this order.
 
 This is a simple wrapper around the API used in the official apps. The author
 provides no investment, legal, or tax advice and is not responsible for any
-damages incured while using this software. Neither this software nor its
+damages incurred while using this software. Neither this software nor its
 author are affiliated with Robinhood Financial LLC in any way.
 
 For Robinhood's terms and disclosures, please see their website at http://robinhood.com/
