@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 use Moo;
 use JSON::Tiny qw[decode_json];
 use strictures 2;
@@ -73,13 +73,14 @@ sub delete_instrument {
               Finance::Robinhood::endpoint('watchlists') . $self->name() . '/' . $instrument->id() . '/');
     return $status == 204;
 }
+
 1;
 
 =encoding utf-8
 
 =head1 NAME
 
-Finance::Robinhood::Watchlist - Persistant List of Financial Instruments
+Finance::Robinhood::Watchlist - Persistent List of Financial Instruments
 
 =head1 SYNOPSIS
 
@@ -93,16 +94,29 @@ Finance::Robinhood::Watchlist - Persistant List of Financial Instruments
 
 =head1 DESCRIPTION
 
-Robinhood allows persistant, categorized lists of financial instruments in
-'watchlists'. The 'Default' watchlist is created by the official Robinhood
-apps and are preloaded with popular securities.
+Robinhood allows persistent, categorized lists of financial instruments in
+'watchlists'. Watchlists are tied to a user rather than a single
+L<account|Finance::Robinhood::Account>.
 
-If you intend to create your own, please use
-C<Finance::Robinhood->create_watchlist( ... )>.
+If you intend to create your own watchlists, please use the
+C<create_watchlist( ... )> method of Finance::Robinhood.
 
 =head1 METHODS
 
-Watchlists are rather simple in themselves.
+Watchlists are rather simple in themselves but can be very powerful for
+organization. Let's say you have a really short list of stocks you'd really
+like to keep an eye on, you could add just those securities to a watchlist. Or
+You could add a watchlist for securities in a certain field.
+
+=head2 C<name( )>
+
+Returns the name given to this watchlist. The official apps use a watchlist
+named 'Default'.
+
+=head2 C<instruments( )>
+
+Returns a paginated list of Finance::Robinhood::Instrument objects being kept
+track of in this watchlist.
 
 =head2 C<delete_instrument( ... )>
 
@@ -123,13 +137,14 @@ second time will fail.
 
 Add multiple instruments in a single API call and by their symbols with this.
 
-...easier than looping through the symbols yourself, right?
+...easier than gathering ::Instrument objects and calling
+C<add_instrument( ... )> for each individual security, right?
 
 =head1 LEGAL
 
 This is a simple wrapper around the API used in the official apps. The author
 provides no investment, legal, or tax advice and is not responsible for any
-damages incured while using this software. Neither this software nor its
+damages incurred while using this software. Neither this software nor its
 author are affiliated with Robinhood Financial LLC in any way.
 
 For Robinhood's terms and disclosures, please see their website at http://robinhood.com/
